==> claromentis-framework-9.6.6-26891208.zip: web/intranet/infocapture/classes/Event/FieldPermissionsInsertEvent.php <==
<?php
namespace Claromentis\Infocapture\Event;

$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"] = (@$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] ?: array()) + array();
use Claromentis\Core\Event\Event;
use Claromentis\Infocapture\Model\ICFieldGroup;
class FieldPermissionsInsertEvent extends Event implements ProjectEventInterface
{
    protected $project;
    protected $rule;
    protected $group;
    protected $old_rights;
    protected $new_rights;
    public function __construct(\HDProject $project, \HDFieldsRule $_4b020cf7a9abbc88937c40b6bc7a97e9, ICFieldGroup $_e9208e4fb555ac989f7519e19c1da810, ?array $_78fbe45e44d96605581b5aafafae39f7, array $_e77c0d109dfc669bb27d74d3ca7bda3d)
    {
        $this->project = $project;
        $this->rule = $_4b020cf7a9abbc88937c40b6bc7a97e9;
        $this->group = $_e9208e4fb555ac989f7519e19c1da810;
        $this->old_rights = $_78fbe45e44d96605581b5aafafae39f7;
        $this->new_rights = $_e77c0d109dfc669bb27d74d3ca7bda3d;
    }
    
    
    
    
    public function getProject() : \HDProject
    {
        return $this->project;
    }
    
    
    
    
    public function getRule() : \HDFieldsRule
    {
        return $this->rule;
    }
    
    
    
    
    public function getGroup() : ICFieldGroup
    {
        return $this->group;
    }
    
    
    
    
    public function getOldRights() : ?array
    {
        return $this->old_rights;
    }
    
    
    
    
    public function getNewRights() : array
    {
        return $this->new_rights;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/infocapture/classes/Event/FieldPermissionsInsertEvent.php <==
<?php
namespace Claromentis\Infocapture\Event;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"] = (@$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] ?: array()) + array();
use Claromentis\Core\Event\Event;
use Claromentis\Infocapture\Model\ICFieldGroup;
class FieldPermissionsInsertEvent extends Event implements ProjectEventInterface
{
    protected $project;
    protected $rule;
    protected $group;
    protected $old_rights;
    protected $new_rights;
    public function __construct(\HDProject $project, \HDFieldsRule $_4b020cf7a9abbc88937c40b6bc7a97e9, ICFieldGroup $_e9208e4fb555ac989f7519e19c1da810, ?array $_78fbe45e44d96605581b5aafafae39f7, array $_e77c0d109dfc669bb27d74d3ca7bda3d)
    {
        $this->project = $project;
        $this->rule = $_4b020cf7a9abbc88937c40b6bc7a97e9;
        $this->group = $_e9208e4fb555ac989f7519e19c1da810;
        $this->old_rights = $_78fbe45e44d96605581b5aafafae39f7;
        $this->new_rights = $_e77c0d109dfc669bb27d74d3ca7bda3d;
    }
    
    
    
    
    public function getProject() : \HDProject
    {
        return $this->project;
    }
    
    
    
    
    public function getRule() : \HDFieldsRule
    {
        return $this->rule;
    }
    
    
    
    
    public function getGroup() : ICFieldGroup
    {
        return $this->group;
    }
    
    
    
    
    public function getOldRights() : ?array
    {
        return $this->old_rights;
    }
    
    
    
    
    public function getNewRights() : array
    {
        return $this->new_rights;
    }
}
